ByteBufferDataInputStream.copy constructor

ByteBufferDataInputStream.copy(
  1. ByteBufferDataInputStream other
)

Create a copy of ths input stream with the same underlying data as other at the same position.

Implementation

ByteBufferDataInputStream.copy(ByteBufferDataInputStream other)
  : _source = other._source,
    _asByteData = other._asByteData,
    seek = other.seek,
    endian = other.endian;